<?php

/**
 * _ntm_m_get_names().
 * _ntm_t_get_names().
 * _ntm_m_get_flat_tree().
 * _ntm_t_get_flat_tree().
 * _ntm_flat_tree_render().
 */

function _ntm_m_get_names() {
  $names = menu_get_menus();
  return $names;
}


function _ntm_t_get_names() {
  $options = module_exists('taxonomy') ? taxonomy_vocabulary_get_names() : NULL;
  $names = array();
  if ($options) {
    foreach ($options as $item) {
      $names[$item->vid] = $item->name;
    }
  }
  return $names;
}


function _ntm_m_get_flat_tree($source_id, $iid = 0, $max_depth = NTM_MAX_DEPTH) {
  if ($iid) {
    $root_info = menu_link_load($iid);
  }
  $cache = &drupal_static('ntm_menu_cache', array());
  $cache_id = $source_id.$iid.$max_depth;
  if (!isset($cache[$cache_id])) {
    $cache[$cache_id] = menu_build_tree($source_id, array('max_depth' => (isset($root_info) ? $root_info['depth'] + $max_depth : $max_depth)));
  }
  $tree = $cache[$cache_id];
  if ($iid) {
    $tree = _ntm_m_get_sub_tree($tree, $iid);
    $tree = $tree['below'];
  }
  if ($tree) {
    $tree = _ntm_m_items_collect(menu_tree_output($tree));
    if (isset($root_info)) {
      foreach ($tree as $item) {
        $item->depth-= $root_info['depth'];
      }
    }
  }
  return $tree;
}


function _ntm_t_get_flat_tree($source_id, $iid = 0, $max_depth = NTM_MAX_DEPTH) {
  $tree = module_exists('taxonomy') ? taxonomy_get_tree($source_id, $iid, $max_depth) : NULL;
  if ($tree) {
    foreach ($tree as $node) {
      $node->depth++;
      $node->iid = $node->tid;
      $node->url = "taxonomy/term/$node->iid";
      $node->title = $node->name;
    }
  }
  return $tree;
}


function _ntm_flat_tree_render($tree, $style = 'down') {
  $output = '<div class="menu-ntm menu-ntm-'.$style.' clearfix"><ul>'."\n";
  for ($i = 0; $i < count($tree); $i++) {
    $c_item = $tree[$i];
    $p_item = isset($tree[$i-1]) ? $tree[$i-1] : null;
    $f_item = isset($tree[$i+1]) ? $tree[$i+1] : null;
    $class = array();
    if ($f_item && $c_item->depth < $f_item->depth) $class[]= 'has_child';
    if ($i == 0 || ($p_item && $c_item->depth > $p_item->depth)) $class[]= 'first';
    if ($f_item == null || $c_item->depth > $f_item->depth) $class[]= 'last';
    $output.= "\n<li".(count($class) ? ' class="'.implode(' ', $class).'"' : '').">";
    $output.= l($c_item->title, $c_item->url);
    if      ($f_item && $c_item->depth < $f_item->depth) $output.= '<ul>';
    else if ($f_item && $c_item->depth > $f_item->depth) $output.= '</li>'.str_repeat('</ul></li>', $c_item->depth-$f_item->depth);
    else if ($f_item == null) $output.= '</li>'.str_repeat('</ul></li>', $c_item->depth-1);
    else $output.= '</li>';
  }
  $output.= '</ul></div>';
  return $output;
}


/**
 * _ntm_m_get_sub_tree().
 * _ntm_m_items_collect().
 */

function _ntm_m_get_sub_tree($tree, $iid) {
  foreach ($tree as $node) {
    if ($node['link'] && $node['link']['mlid'] == $iid) return $node;
    if ($node['below']) {
      $node = _ntm_m_get_sub_tree($node['below'], $iid);
      if ($node) return $node;
    }
  }
}


function _ntm_m_items_collect($tree, &$info = array()) {
  foreach ($tree as $node) {
    if (isset($node['#original_link'])) {
      $link = $node['#original_link'];
      if ($link['type'] == MENU_NORMAL_ITEM) {
        $info[]= (object)array(
          'iid'   => $link['mlid'],
          'url'   => $link['href'],
          'title' => $link['title'],
          'depth' => $link['depth'],
        );
      }
    }
    if (isset($node['#below'])) {
      _ntm_m_items_collect($node['#below'], $info);
    }
  }
  return $info;
}


